import type { CreateTRPCClientOptions } from '@trpc/client';
import type { AnyMutationProcedure, AnyProcedure, AnyQueryProcedure, AnySubscriptionProcedure, AnyRouter, ProcedureArgs, ProcedureRouterRecord, inferProcedureOutput } from '@trpc/server';
import type { inferObservableValue } from '@trpc/server/observable';
import type { Atom, Getter, WritableAtom } from 'jotai';
type ValueOrGetter<T> = T | ((get: Getter) => T);
type QueryResolver<TProcedure extends AnyProcedure, TClient> = (getInput: ValueOrGetter<ProcedureArgs<TProcedure['_def']>[0]>, getOptions?: ValueOrGetter<ProcedureArgs<TProcedure['_def']>[1]>, getClient?: (get: Getter) => TClient) => Atom<Promise<inferProcedureOutput<TProcedure>>>;
type MutationResolver<TProcedure extends AnyProcedure, TClient> = (getClient?: (get: Getter) => TClient) => WritableAtom<inferProcedureOutput<TProcedure> | null, ProcedureArgs<TProcedure['_def']>>;
type SubscriptionResolver<TProcedure extends AnyProcedure, TClient> = (getInput: ValueOrGetter<ProcedureArgs<TProcedure['_def']>[0]>, getOptions?: ValueOrGetter<ProcedureArgs<TProcedure['_def']>[1]>, getClient?: (get: Getter) => TClient) => Atom<inferObservableValue<inferProcedureOutput<TProcedure>>>;
type DecorateProcedure<TProcedure extends AnyProcedure, TClient> = TProcedure extends AnyQueryProcedure ? {
    atomWithQuery: QueryResolver<TProcedure, TClient>;
} : TProcedure extends AnyMutationProcedure ? {
    atomWithMutation: MutationResolver<TProcedure, TClient>;
} : TProcedure extends AnySubscriptionProcedure ? {
    atomWithSubscription: SubscriptionResolver<TProcedure, TClient>;
} : never;
type DecoratedProcedureRecord<TProcedures extends ProcedureRouterRecord, TClient> = {
    [TKey in keyof TProcedures]: TProcedures[TKey] extends AnyRouter ? DecoratedProcedureRecord<TProcedures[TKey]['_def']['record'], TClient> : TProcedures[TKey] extends AnyProcedure ? DecorateProcedure<TProcedures[TKey], TClient> : never;
};
export declare function createTRPCJotai<TRouter extends AnyRouter>(opts: CreateTRPCClientOptions<TRouter>): DecoratedProcedureRecord<TRouter["_def"]["record"], TRouter["_def"]["record"] extends infer T extends ProcedureRouterRecord ? { [TKey in keyof T]: TRouter["_def"]["record"][TKey] extends AnyRouter ? TRouter["_def"]["record"][TKey]["_def"]["record"] extends infer T_1 extends ProcedureRouterRecord ? { [TKey_1 in keyof T_1]: TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1] extends AnyRouter ? TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"] extends infer T_2 extends ProcedureRouterRecord ? { [TKey_2 in keyof T_2]: TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2] extends AnyRouter ? TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"] extends infer T_3 extends ProcedureRouterRecord ? { [TKey_3 in keyof T_3]: TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3] extends AnyRouter ? TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"] extends infer T_4 extends ProcedureRouterRecord ? { [TKey_4 in keyof T_4]: TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4] extends AnyRouter ? TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"] extends infer T_5 extends ProcedureRouterRecord ? { [TKey_5 in keyof T_5]: TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5] extends AnyRouter ? TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"] extends infer T_6 extends ProcedureRouterRecord ? { [TKey_6 in keyof T_6]: TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6] extends AnyRouter ? TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"] extends infer T_7 extends ProcedureRouterRecord ? { [TKey_7 in keyof T_7]: TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7] extends AnyRouter ? TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"] extends infer T_8 extends ProcedureRouterRecord ? { [TKey_8 in keyof T_8]: TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8] extends AnyRouter ? TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8]["_def"]["record"] extends infer T_9 extends ProcedureRouterRecord ? { [TKey_9 in keyof T_9]: TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8]["_def"]["record"][TKey_9] extends AnyRouter ? TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8]["_def"]["record"][TKey_9]["_def"]["record"] extends infer T_10 extends ProcedureRouterRecord ? { [TKey_10 in keyof T_10]: TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8]["_def"]["record"][TKey_9]["_def"]["record"][TKey_10] extends AnyRouter ? any : TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8]["_def"]["record"][TKey_9]["_def"]["record"][TKey_10] extends AnyProcedure ? TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8]["_def"]["record"][TKey_9]["_def"]["record"][TKey_10] extends infer T_11 ? T_11 extends TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8]["_def"]["record"][TKey_9]["_def"]["record"][TKey_10] ? T_11 extends AnyQueryProcedure ? {
    query: (...args: ProcedureArgs<T_11["_def"]>) => Promise<inferProcedureOutput<T_11>>;
} : T_11 extends AnyMutationProcedure ? {
    mutate: (...args: ProcedureArgs<T_11["_def"]>) => Promise<inferProcedureOutput<T_11>>;
} : T_11 extends AnySubscriptionProcedure ? {
    subscribe: (input: ProcedureArgs<T_11["_def"]>[0], opts: ProcedureArgs<T_11["_def"]>[1] & Partial<import("@trpc/client/dist/internals/TRPCClient").TRPCSubscriptionObserver<inferObservableValue<inferProcedureOutput<T_11>>, import("@trpc/client").TRPCClientError<TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8]["_def"]["record"][TKey_9]>>>) => import("@trpc/server/observable").Unsubscribable;
} : never : never : never : never; } : never : TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8]["_def"]["record"][TKey_9] extends AnyProcedure ? TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8]["_def"]["record"][TKey_9] extends infer T_12 ? T_12 extends TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8]["_def"]["record"][TKey_9] ? T_12 extends AnyQueryProcedure ? {
    query: (...args: ProcedureArgs<T_12["_def"]>) => Promise<inferProcedureOutput<T_12>>;
} : T_12 extends AnyMutationProcedure ? {
    mutate: (...args: ProcedureArgs<T_12["_def"]>) => Promise<inferProcedureOutput<T_12>>;
} : T_12 extends AnySubscriptionProcedure ? {
    subscribe: (input: ProcedureArgs<T_12["_def"]>[0], opts: ProcedureArgs<T_12["_def"]>[1] & Partial<import("@trpc/client/dist/internals/TRPCClient").TRPCSubscriptionObserver<inferObservableValue<inferProcedureOutput<T_12>>, import("@trpc/client").TRPCClientError<TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8]>>>) => import("@trpc/server/observable").Unsubscribable;
} : never : never : never : never; } : never : TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8] extends AnyProcedure ? TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8] extends infer T_13 ? T_13 extends TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]["_def"]["record"][TKey_8] ? T_13 extends AnyQueryProcedure ? {
    query: (...args: ProcedureArgs<T_13["_def"]>) => Promise<inferProcedureOutput<T_13>>;
} : T_13 extends AnyMutationProcedure ? {
    mutate: (...args: ProcedureArgs<T_13["_def"]>) => Promise<inferProcedureOutput<T_13>>;
} : T_13 extends AnySubscriptionProcedure ? {
    subscribe: (input: ProcedureArgs<T_13["_def"]>[0], opts: ProcedureArgs<T_13["_def"]>[1] & Partial<import("@trpc/client/dist/internals/TRPCClient").TRPCSubscriptionObserver<inferObservableValue<inferProcedureOutput<T_13>>, import("@trpc/client").TRPCClientError<TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7]>>>) => import("@trpc/server/observable").Unsubscribable;
} : never : never : never : never; } : never : TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7] extends AnyProcedure ? TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7] extends infer T_14 ? T_14 extends TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]["_def"]["record"][TKey_7] ? T_14 extends AnyQueryProcedure ? {
    query: (...args: ProcedureArgs<T_14["_def"]>) => Promise<inferProcedureOutput<T_14>>;
} : T_14 extends AnyMutationProcedure ? {
    mutate: (...args: ProcedureArgs<T_14["_def"]>) => Promise<inferProcedureOutput<T_14>>;
} : T_14 extends AnySubscriptionProcedure ? {
    subscribe: (input: ProcedureArgs<T_14["_def"]>[0], opts: ProcedureArgs<T_14["_def"]>[1] & Partial<import("@trpc/client/dist/internals/TRPCClient").TRPCSubscriptionObserver<inferObservableValue<inferProcedureOutput<T_14>>, import("@trpc/client").TRPCClientError<TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6]>>>) => import("@trpc/server/observable").Unsubscribable;
} : never : never : never : never; } : never : TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6] extends AnyProcedure ? TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6] extends infer T_15 ? T_15 extends TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]["_def"]["record"][TKey_6] ? T_15 extends AnyQueryProcedure ? {
    query: (...args: ProcedureArgs<T_15["_def"]>) => Promise<inferProcedureOutput<T_15>>;
} : T_15 extends AnyMutationProcedure ? {
    mutate: (...args: ProcedureArgs<T_15["_def"]>) => Promise<inferProcedureOutput<T_15>>;
} : T_15 extends AnySubscriptionProcedure ? {
    subscribe: (input: ProcedureArgs<T_15["_def"]>[0], opts: ProcedureArgs<T_15["_def"]>[1] & Partial<import("@trpc/client/dist/internals/TRPCClient").TRPCSubscriptionObserver<inferObservableValue<inferProcedureOutput<T_15>>, import("@trpc/client").TRPCClientError<TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5]>>>) => import("@trpc/server/observable").Unsubscribable;
} : never : never : never : never; } : never : TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5] extends AnyProcedure ? TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5] extends infer T_16 ? T_16 extends TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]["_def"]["record"][TKey_5] ? T_16 extends AnyQueryProcedure ? {
    query: (...args: ProcedureArgs<T_16["_def"]>) => Promise<inferProcedureOutput<T_16>>;
} : T_16 extends AnyMutationProcedure ? {
    mutate: (...args: ProcedureArgs<T_16["_def"]>) => Promise<inferProcedureOutput<T_16>>;
} : T_16 extends AnySubscriptionProcedure ? {
    subscribe: (input: ProcedureArgs<T_16["_def"]>[0], opts: ProcedureArgs<T_16["_def"]>[1] & Partial<import("@trpc/client/dist/internals/TRPCClient").TRPCSubscriptionObserver<inferObservableValue<inferProcedureOutput<T_16>>, import("@trpc/client").TRPCClientError<TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4]>>>) => import("@trpc/server/observable").Unsubscribable;
} : never : never : never : never; } : never : TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4] extends AnyProcedure ? TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4] extends infer T_17 ? T_17 extends TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]["_def"]["record"][TKey_4] ? T_17 extends AnyQueryProcedure ? {
    query: (...args: ProcedureArgs<T_17["_def"]>) => Promise<inferProcedureOutput<T_17>>;
} : T_17 extends AnyMutationProcedure ? {
    mutate: (...args: ProcedureArgs<T_17["_def"]>) => Promise<inferProcedureOutput<T_17>>;
} : T_17 extends AnySubscriptionProcedure ? {
    subscribe: (input: ProcedureArgs<T_17["_def"]>[0], opts: ProcedureArgs<T_17["_def"]>[1] & Partial<import("@trpc/client/dist/internals/TRPCClient").TRPCSubscriptionObserver<inferObservableValue<inferProcedureOutput<T_17>>, import("@trpc/client").TRPCClientError<TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3]>>>) => import("@trpc/server/observable").Unsubscribable;
} : never : never : never : never; } : never : TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3] extends AnyProcedure ? TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3] extends infer T_18 ? T_18 extends TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]["_def"]["record"][TKey_3] ? T_18 extends AnyQueryProcedure ? {
    query: (...args: ProcedureArgs<T_18["_def"]>) => Promise<inferProcedureOutput<T_18>>;
} : T_18 extends AnyMutationProcedure ? {
    mutate: (...args: ProcedureArgs<T_18["_def"]>) => Promise<inferProcedureOutput<T_18>>;
} : T_18 extends AnySubscriptionProcedure ? {
    subscribe: (input: ProcedureArgs<T_18["_def"]>[0], opts: ProcedureArgs<T_18["_def"]>[1] & Partial<import("@trpc/client/dist/internals/TRPCClient").TRPCSubscriptionObserver<inferObservableValue<inferProcedureOutput<T_18>>, import("@trpc/client").TRPCClientError<TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2]>>>) => import("@trpc/server/observable").Unsubscribable;
} : never : never : never : never; } : never : TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2] extends AnyProcedure ? TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2] extends infer T_19 ? T_19 extends TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]["_def"]["record"][TKey_2] ? T_19 extends AnyQueryProcedure ? {
    query: (...args: ProcedureArgs<T_19["_def"]>) => Promise<inferProcedureOutput<T_19>>;
} : T_19 extends AnyMutationProcedure ? {
    mutate: (...args: ProcedureArgs<T_19["_def"]>) => Promise<inferProcedureOutput<T_19>>;
} : T_19 extends AnySubscriptionProcedure ? {
    subscribe: (input: ProcedureArgs<T_19["_def"]>[0], opts: ProcedureArgs<T_19["_def"]>[1] & Partial<import("@trpc/client/dist/internals/TRPCClient").TRPCSubscriptionObserver<inferObservableValue<inferProcedureOutput<T_19>>, import("@trpc/client").TRPCClientError<TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1]>>>) => import("@trpc/server/observable").Unsubscribable;
} : never : never : never : never; } : never : TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1] extends AnyProcedure ? TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1] extends infer T_20 ? T_20 extends TRouter["_def"]["record"][TKey]["_def"]["record"][TKey_1] ? T_20 extends AnyQueryProcedure ? {
    query: (...args: ProcedureArgs<T_20["_def"]>) => Promise<inferProcedureOutput<T_20>>;
} : T_20 extends AnyMutationProcedure ? {
    mutate: (...args: ProcedureArgs<T_20["_def"]>) => Promise<inferProcedureOutput<T_20>>;
} : T_20 extends AnySubscriptionProcedure ? {
    subscribe: (input: ProcedureArgs<T_20["_def"]>[0], opts: ProcedureArgs<T_20["_def"]>[1] & Partial<import("@trpc/client/dist/internals/TRPCClient").TRPCSubscriptionObserver<inferObservableValue<inferProcedureOutput<T_20>>, import("@trpc/client").TRPCClientError<TRouter["_def"]["record"][TKey]>>>) => import("@trpc/server/observable").Unsubscribable;
} : never : never : never : never; } : never : TRouter["_def"]["record"][TKey] extends AnyProcedure ? TRouter["_def"]["record"][TKey] extends infer T_21 ? T_21 extends TRouter["_def"]["record"][TKey] ? T_21 extends AnyQueryProcedure ? {
    query: (...args: ProcedureArgs<T_21["_def"]>) => Promise<inferProcedureOutput<T_21>>;
} : T_21 extends AnyMutationProcedure ? {
    mutate: (...args: ProcedureArgs<T_21["_def"]>) => Promise<inferProcedureOutput<T_21>>;
} : T_21 extends AnySubscriptionProcedure ? {
    subscribe: (input: ProcedureArgs<T_21["_def"]>[0], opts: ProcedureArgs<T_21["_def"]>[1] & Partial<import("@trpc/client/dist/internals/TRPCClient").TRPCSubscriptionObserver<inferObservableValue<inferProcedureOutput<T_21>>, import("@trpc/client").TRPCClientError<TRouter>>>) => import("@trpc/server/observable").Unsubscribable;
} : never : never : never : never; } : never>;
export {};
